@@ -54,7 +54,15 @@ module TapKit
 		end
 
 		# abstract
-		def bind_variable( attribute, value ); end
+		def bind_variable( attribute, value )
+			binding                  = {}
+			binding[NAME_KEY]        = attribute.name
+			binding[PLACEHOLDER_KEY] = '?'
+			binding[ATTRIBUTE_KEY]   = attribute
+			binding[VALUE_KEY]       = value
+			binding
+		end
+
 		def must_use_bind_variable?( attribute ); end
 		def should_use_bind_variable?( attribute ); end
 
@@ -226,7 +234,10 @@ module TapKit
 				return
 			end
 
-			@aliases.each do |path, another|
+			@join_entities.each do |entity|
+				name    = entity[0].name
+				another = entity[1]
+				path    = @aliases.index another
 				if relationship = @join_relationships[path] then
 					relationship.joins.each do |join|
 						_join_expression(relationship, join)
@@ -242,16 +253,16 @@ module TapKit
 
 			if set = @join_entities.assoc(join.source.entity) then
 				another = set[1]
-				left = "#{another}.#{join.source.name}"
+				left = "#{another}.#{join.source.column_name}"
 			elsif @entity == join.source.entity then
-				left = "#{@aliases['']}.#{join.source.name}"
+				left = "#{@aliases['']}.#{join.source.column_name}"
 			end
 
 			if set = @join_entities.assoc(join.destination.entity) then
 				another = set[1]
-				right = "#{another}.#{join.destination.name}"
+				right = "#{another}.#{join.destination.column_name}"
 			elsif @entity == join.destination.entity then
-				right = "#{@aliases['']}.#{join.destination.name}"
+				right = "#{@aliases['']}.#{join.destination.column_name}"
 			end
 
 			add_join(left, right, relationship.join_semantic)
@@ -504,8 +515,17 @@ module TapKit
 		## format
 		##
 
-		# abstract
-		def format_value( value, attribute ); end
+		# abstract method. this is default implementation.
+		def format_value( value, attribute )
+			case attribute.adapter_value_type
+			when Attribute::ADAPTER_CHARACTERS_TYPE then sql_for_string value
+			when Attribute::ADAPTER_DATE_TYPE       then sql_for_date value
+			when Attribute::ADAPTER_NUMBER_TYPE     then sql_for_number value
+			when Attribute::ADAPTER_BYTES_TYPE      then sql_for_data value
+			else
+				raise "unsupported type: '#{attribute.external_type}'"
+			end
+		end
 
 		def format_sql_string( sql, format = nil )
 			unless format then
@@ -556,6 +576,7 @@ module TapKit
 			last_attr = nil
 			re_path = ''
 			re = nil
+
 			paths.each_with_index do |path, index|
 				if (index + 1) == paths.size then
 					last_attr = last_entity.attribute path
@@ -638,13 +659,17 @@ module TapKit
 			if date.nil? then
 				'NULL'
 			else
-				date.to_s
+				"'#{date.to_s}'"
 			end
 		end
 
 		def sql_for_number( number )
 			if number.nil? then
 				'NULL'
+			elsif number == true then
+				1
+			elsif number == false then
+				0
 			else
 				number.to_s
 			end
