@@ -4,6 +4,8 @@ module TapKit
 		class << self
 			# jis, sjis, euc
 			def encode( string, encoding )
+				unless String === string then return string end
+				require 'kconv'
 				case encoding
 				when 'jis'
 					encoding = Kconv::JIS
@@ -14,7 +16,6 @@ module TapKit
 				else
 					return string
 				end
-
 				string.kconv encoding
 			end
 		end
