@@ -4,17 +4,17 @@ class TestQualifier < Test::Unit::TestCase
 	# operators
 
 	def test_operators
-		expected = ['==', '!=', '<', '<=', '>', '>=', 'like', 'cilike']
+		expected = ['=', '==', '!=', '<', '<=', '>', '>=', 'like', 'cilike']
 		assert_equal(expected, Qualifier.operators)
 	end
 
 	def test_relational_operators
-		expected = ['==', '!=', '<', '<=', '>', '>=']
+		expected = ['=', '==', '!=', '<', '<=', '>', '>=']
 		assert_equal(expected, Qualifier.relational_operators)
 	end
 
 	def test_operator_symbol
-		expected = { 'dummylike' => nil,
+		expected = { 'dummylike' => nil, '=' => Qualifier::EQUAL,
 			'=='   => Qualifier::EQUAL,   '!='     => Qualifier::NOT_EQUAL, 
 			'>'    => Qualifier::GREATER, '>='     => Qualifier::GREATER_OR_EQUAL,
 			'<'    => Qualifier::LESS,    '<='     => Qualifier::LESS_OR_EQUAL,
@@ -27,7 +27,7 @@ class TestQualifier < Test::Unit::TestCase
 
 	def test_operator_string
 		expected = { 'dummy' => nil,
-			Qualifier::EQUAL   => '==',   Qualifier::NOT_EQUAL        => '!=',
+			Qualifier::EQUAL   => '=' ,   Qualifier::NOT_EQUAL        => '!=',
 			Qualifier::GREATER => '>',    Qualifier::GREATER_OR_EQUAL => '>=',
 			Qualifier::LESS    => '<',    Qualifier::LESS_OR_EQUAL    => '<=',
 			Qualifier::LIKE    => 'like', Qualifier::CI_LIKE          => 'cilike' }
@@ -42,7 +42,7 @@ class TestQualifier < Test::Unit::TestCase
 
 	def test_new_to_match_all_values
 		values    = {'title' => 'test', 'number' => 1}
-		expected  = "((number == 1) AND (title == 'test'))"
+		expected  = "((number = 1) AND (title = 'test'))"
 		qualifier = Qualifier.new_to_match_all_values values
 
 		assert_equal(expected, qualifier.to_s)
@@ -51,7 +51,7 @@ class TestQualifier < Test::Unit::TestCase
 
 	def test_new_to_match_any_value
 		values    = {'title' => 'test', 'number' => 1}
-		expected  = "((number == 1) OR (title == 'test'))"
+		expected  = "((number = 1) OR (title = 'test'))"
 		qualifier = Qualifier.new_to_match_any_value values
 
 		assert_equal(expected, qualifier.to_s)
@@ -66,24 +66,127 @@ class TestQualifier < Test::Unit::TestCase
 
 	# filter
 
-	def test_filter
-		qualifier = Qualifier.format "title == 'test'"
+	def test_filter_equal
+		qualifier = Qualifier.format "title = 'test'"
 		app       = Application.new MODELS
 		ec        = app.create_editing_context
-
-		object1 = ec.create 'Book'
-		object2 = ec.create 'Book'
-		object3 = ec.create 'Book'
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
 		object1['title'] = 'test'
 		object2['title'] = 'dummy'
 		object3['title'] = 'test'
-
 		array    = [object1, object2, object3]
 		expected = [object1, object3]
-
 		assert_equal(expected, Qualifier.filter(array, qualifier))
 	end
 
+	def test_filter_not_equal
+		qualifier = Qualifier.format "title != 'test'"
+		app       = Application.new MODELS
+		ec        = app.create_editing_context
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
+		object1['title'] = 'test'
+		object2['title'] = 'dummy'
+		object3['title'] = 'test'
+		array    = [object1, object2, object3]
+		expected = [object2]
+		assert_equal(expected, Qualifier.filter(array, qualifier))
+	end
+
+	def test_filter_greater
+		qualifier = Qualifier.format "release > 50"
+		app       = Application.new MODELS
+		ec        = app.create_editing_context
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
+		object1['release'] = 10
+		object2['release'] = 50
+		object3['release'] = 100
+		array    = [object1, object2, object3]
+		expected = [object3]
+		assert_equal(expected, Qualifier.filter(array, qualifier))
+	end
+
+	def test_filter_greater_or_equal
+		qualifier = Qualifier.format "release >= 50"
+		app       = Application.new MODELS
+		ec        = app.create_editing_context
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
+		object1['release'] = 10
+		object2['release'] = 50
+		object3['release'] = 100
+		array    = [object1, object2, object3]
+		expected = [object2, object3]
+		assert_equal(expected, Qualifier.filter(array, qualifier))
+	end
+
+	def test_filter_less
+		qualifier = Qualifier.format "release < 50"
+		app       = Application.new MODELS
+		ec        = app.create_editing_context
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
+		object1['release'] = 10
+		object2['release'] = 50
+		object3['release'] = 100
+		array    = [object1, object2, object3]
+		expected = [object1]
+		assert_equal(expected, Qualifier.filter(array, qualifier))
+	end
+
+	def test_filter_less_or_equal
+		qualifier = Qualifier.format "release <= 50"
+		app       = Application.new MODELS
+		ec        = app.create_editing_context
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
+		object1['release'] = 10
+		object2['release'] = 50
+		object3['release'] = 100
+		array    = [object1, object2, object3]
+		expected = [object1, object2]
+		assert_equal(expected, Qualifier.filter(array, qualifier))
+	end
+
+	def test_filter_like
+		qualifier = Qualifier.format "title like 'a*'"
+		app       = Application.new MODELS
+		ec        = app.create_editing_context
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
+		object1['title'] = 'abcde'
+		object2['title'] = 'bcdea'
+		object3['title'] = 'ABCDE'
+		array    = [object1, object2, object3]
+		expected = [object1]
+		assert_equal(expected, Qualifier.filter(array, qualifier))
+	end
+
+	def test_filter_cilike
+		qualifier = Qualifier.format "title cilike 'a*'"
+		app       = Application.new MODELS
+		ec        = app.create_editing_context
+		object1 = ec.create 'cd'
+		object2 = ec.create 'cd'
+		object3 = ec.create 'cd'
+		object1['title'] = 'abcde'
+		object2['title'] = 'bcdea'
+		object3['title'] = 'ABCDE'
+		array    = [object1, object2, object3]
+		expected = [object1, object3]
+		assert_equal(expected, Qualifier.filter(array, qualifier))
+	end
+
+
 
 	# validate
 
@@ -107,7 +210,9 @@ class TestQualifier < Test::Unit::TestCase
 		left = "title like"
 		tokens = { "'*'" => String, '"*"' => String, '100' => Fixnum, '0.1' => Float,
 			'true' => TrueClass, 'false' => FalseClass, 'nil' => NilClass,
-			'true_dummy' => String }
+			'true_dummy' => String, "(Integer)'1'" => Fixnum,
+			"(Date)'2003-12-15'"=>TapKit::Date, "(Time)'12:30:30'"=>TapKit::Time,
+			"(Timestamp)'2003-12-15 12:30:30 +0900'"=>TapKit::Timestamp }
 
 		tokens.each do |right, expected|
 			format = "#{left} #{right}"
@@ -124,6 +229,7 @@ class TestQualifier < Test::Unit::TestCase
 
 	def test_parser_for_operator
 		operators = {
+			'='    => Qualifier::EQUAL,
 			'=='   => Qualifier::EQUAL,   '!='     => Qualifier::NOT_EQUAL, 
 			'>'    => Qualifier::GREATER, '>='     => Qualifier::GREATER_OR_EQUAL,
 			'<'    => Qualifier::LESS,    '<='     => Qualifier::LESS_OR_EQUAL,
@@ -162,7 +268,15 @@ class TestQualifier < Test::Unit::TestCase
 			{:convert => '%K', :bindings => true,    :expected => true,   :key => false},
 			{:convert => '%K', :bindings => false,   :expected => false,  :key => false},
 			{:convert => '%K', :bindings => nil,     :expected => nil,    :key => false},
-			{:convert => "'%%'", :bindings => 'dummy', :expected => '%',  :key => false}
+			{:convert => "'%%'", :bindings => 'dummy', :expected => '%',  :key => false},
+			{:convert => '%@', :bindings => Date.new(2003,12,15),
+				:expected => Date.new(2003,12,15), :key => false},
+			{:convert => '%@', :bindings => Time.new(12,30,30),
+				:expected => Time.new(12,30,30), :key => false},
+			{:convert => '%@', :bindings => Timestamp.new(2003,12,15,12,30,30),
+				:expected => Timestamp.new(2003,12,15,12,30,30), :key => false},
+			{:convert => '%@', :bindings => Array(1),
+				:expected => Array('1'), :key => false}
 		]
 
 		tests.each do |test|
@@ -199,7 +313,7 @@ class TestQualifier < Test::Unit::TestCase
 	end
 
 	def test_parser_for_and
-		expected_format = "((title like '*') AND (name == 'John'))"
+		expected_format = "((title like '*') AND (name = 'John'))"
 		keyvalue1 = KeyValueQualifier.new('title', Qualifier::LIKE, '*')
 		keyvalue2 = KeyValueQualifier.new('name', Qualifier::EQUAL, 'John')
 		expected_qualifier = AndQualifier.new [keyvalue1, keyvalue2]
@@ -210,7 +324,7 @@ class TestQualifier < Test::Unit::TestCase
 	end
 
 	def test_parser_for_or
-		expected_format = "((title like '*') OR (name == 'John'))"
+		expected_format = "((title like '*') OR (name = 'John'))"
 		keyvalue1 = KeyValueQualifier.new('title', Qualifier::LIKE, '*')
 		keyvalue2 = KeyValueQualifier.new('name', Qualifier::EQUAL, 'John')
 		expected_qualifier = OrQualifier.new [keyvalue1, keyvalue2]
@@ -221,7 +335,7 @@ class TestQualifier < Test::Unit::TestCase
 	end
 
 	def test_parser_for_not
-		expected_format = "(NOT ((title like '*') AND (name == 'John')))"
+		expected_format = "(NOT ((title like '*') AND (name = 'John')))"
 		keyvalue1 = KeyValueQualifier.new('title', Qualifier::LIKE, '*')
 		keyvalue2 = KeyValueQualifier.new('name', Qualifier::EQUAL, 'John')
 		and_qualifier = AndQualifier.new [keyvalue1, keyvalue2]
@@ -270,7 +384,7 @@ class TestKeyValueQualifier < Test::Unit::TestCase
 	end
 
 	def test_to_s
-		expected = "(key == 'value')"
+		expected = "(key = 'value')"
 
 		assert_equal(expected, @qualifier.to_s)
 	end
@@ -316,7 +430,7 @@ class TestKeyComparisonQualifier < Test::Unit::TestCase
 	end
 
 	def test_to_s
-		expected  = "(left == right.path)"
+		expected  = "(left = right.path)"
 
 		assert_equal(expected, @qualifier.to_s)
 	end
@@ -365,7 +479,7 @@ class TestAndQualifier < Test::Unit::TestCase
 	end
 
 	def test_to_s
-		expected = "((key1 == 'value1') AND (key2 == 'value2'))"
+		expected = "((key1 = 'value1') AND (key2 = 'value2'))"
 
 		assert_equal(expected, @qualifier.to_s)
 	end
@@ -414,7 +528,7 @@ class TestOrQualifier < Test::Unit::TestCase
 	end
 
 	def test_to_s
-		expected = "((key1 == 'value1') OR (key2 == 'value2'))"
+		expected = "((key1 = 'value1') OR (key2 = 'value2'))"
 
 		assert_equal(expected, @qualifier.to_s)
 	end
@@ -457,7 +571,7 @@ class TestNotQualifier < Test::Unit::TestCase
 	end
 
 	def test_to_s
-		expected  = "(NOT (key == 'value'))"
+		expected  = "(NOT (key = 'value'))"
 
 		assert_equal(expected, @qualifier.to_s)
 	end
