@@ -265,7 +265,7 @@ class TestSQLExpression < Test::Unit::TestCase
 
 	def test_sql_for_date
 		date = Date.new(2003,1,1)
-		expected = '2003-01-01'
+		expected = "'2003-01-01'"
 
 		assert_equal(expected, @expr.sql_for_date(date))
 		assert_equal('NULL', @expr.sql_for_date(nil))
