@@ -5,6 +5,14 @@ class TestTime < Test::Unit::TestCase
 		@time = Time.new(12,30,30)
 	end
 
+	def test_parse
+		str = '12:30:30'
+		time = Time.parse str
+		assert_equal(12, time.hour)
+		assert_equal(30, time.minute)
+		assert_equal(30, time.second)
+	end
+
 	def test_new
 		time = Time.new(12,30,30)
 		assert_equal(12, time.hour)
